@@ -12,7 +12,7 @@ class Renderer(multiprocessing.Process):
     """
     A Mapnik renderer process.
     """
-    def __init__(self, tile_queue, config, width=constants.DEFAULT_TILE_WIDTH, height=constants.DEFAULT_TILE_HEIGHT, filetype=constants.DEFAULT_FILE_TYPE):
+    def __init__(self, tile_queue, config, width=constants.DEFAULT_WIDTH, height=constants.DEFAULT_HEIGHT, filetype=constants.DEFAULT_FILE_TYPE):
         multiprocessing.Process.__init__(self)
 
         self.config = config
@@ -73,7 +73,7 @@ class TileRenderer(Renderer):
         self.mapnik_map.zoom_to_box(bbox)
         self.mapnik_map.buffer_size = max([half_width, half_height]) 
 
-        # Render image with default Agg renderer
+        # Render image with default renderer
         image = mapnik2.Image(self.width, self.height)
         mapnik2.render(self.mapnik_map, image)
         image.save(filename, self.filetype)
@@ -110,7 +110,7 @@ class FrameRenderer(Renderer):
         self.mapnik_map.zoom_to_box(bbox)
         self.mapnik_map.buffer_size = max([half_width, half_height]) 
 
-        # Render image with default Agg renderer
+        # Render image with default renderer
         image = mapnik2.Image(self.width, self.height)
         mapnik2.render(self.mapnik_map, image)
         image.save(filename, self.filetype)
